@@ -38,7 +38,7 @@ lmomplot <- function(data, u.range, nt = max(50, length(data)),
   if (missing(u.range)) {
     
     u.range <- c(data[1], data[n - 4])
-    u.range <- u.range - .Machine$double.eps^0.5
+    u.range <- u.range - sqrt(.Machine$double.eps)
     
   }
 
