@@ -32,8 +32,8 @@ gpdmple <- function(x, threshold, start, ..., std.err.type =
     stop("``std.err.type'' must be one of 'observed', 'expected' or 'none'")
   
   nlpot <- function(scale, shape) { 
-    ans <- -.C("gpdlik", exceed, nat, threshold, scale,
-                shape, dns = double(1), PACKAGE = "POT")$dns
+    ans <- -.C(POT_do_gpdlik, exceed, nat, threshold, scale,
+                shape, dns = double(1))$dns
 
     if ((shape > 0) & (shape <1))
      ans <- lambda * ((1 / (1 - shape) - 1)^alpha) + ans
